15.48. cdist-type__git(7) — cdist 4.10.4 documentation

# 15.48. cdist-type__git(7)

## 15.48.1. NAME

cdist-type__git - Get and or keep git repositories up-to-date

## 15.48.2. DESCRIPTION

This cdist type allows you to clone git repositories

## 15.48.3. REQUIRED PARAMETERS

source
  Specifies the git remote to clone from

## 15.48.4. OPTIONAL PARAMETERS

state
  Either "present" or "absent", defaults to "present"
branch
  Create this branch by checking out the remote branch of this name Default branch is "master"
group
  Group to chgrp to.
mode
  Unix permissions, suitable for chmod.
owner
  User to chown to.

## 15.48.5. EXAMPLES

    __git /home/services/dokuwiki --source git://github.com/splitbrain/dokuwiki.git

    # Checkout cdist, stay on branch 2.1
    __git /home/nico/cdist --source git://github.com/ungleich/cdist.git --branch 2.1

## 15.48.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 15.48.7. COPYING

Copyright (C) 2012 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.